@@ -19,7 +19,8 @@ class SaveAppUtility:
                         self.new_app_name = vm.AppTemplateName
                     else:
                         self.new_app_name = new_app_name
-                except:
+                except Exception as e:
+                    self.sandbox.automation_api.WriteMessageToReservationOutput(self.sandbox.id, unicode(e))
                     self.new_app_name = self.app_name
 
         self.server_address = server_address
@@ -52,12 +53,12 @@ class SaveAppUtility:
                 self.display_image_result = requests.get(self.display_image_url, allow_redirects=True).content
                 self.display_image_name = os.path.basename(self.display_image_url)
             else:
-                self.display_image_name = self.sandbox.automation_api.GetReservationAppTemplateImage(self.sandbox.id,
-                                                                                                     self.resource_name)
+                self.display_image_result = self.sandbox.automation_api.GetReservationAppTemplateImage(self.sandbox.id,
+                                                                                                       self.resource_name).AppTemplateImage
                 self.display_image_name = 'vm.png'
         except:
-            self.sandbox.automation_api.WriteMessageToReservationOutput(self.sandbox.id,
-                                                                        'Issue getting display image... Using default display image.')
+            #self.sandbox.automation_api.WriteMessageToReservationOutput(self.sandbox.id,
+            #                                                            'Issue getting display image... Using default display image.')
             self.display_image_result = None
             self.display_image_name = 'vm.png'
 
